@@ -1,9 +1,10 @@
 import re
+from os import path
 
 
 def _load_general_words():
     res = []
-    with open("../general_words.txt", 'r') as reader:
+    with open(path.join(path.dirname(__file__), "../general_words.txt"), 'r') as reader:
         line = reader.readline().strip()
         while line:
             res.append(line)
